def add(a, b):
    return a + b


def subtract(a, b):
    return a - b


def multiply(a, b):
    return a * b


def divide(a, b):
    return a / b


def greet(name):
    return "Hello, " + name


def square(a):
    return a * a