from .calculatorbasic import add
from .calculatorbasic import subtract
from .calculatorbasic import multiply
from .calculatorbasic import divide
from .calculatorbasic import greet
from .calculatorbasic import square