from setuptools import setup

setup(name='subbutest_library', # package name
      version='1.0',               # version number
      author="Subramanya Rekhandar",  # author
      description="A test library for Basic Calculator ", 
      packages=['subbutest-library'], # packge directory
      author_email='aicareerof@gmail.com',
      zip_safe=False)